clear all
close all
clc

% Parametros
N = 3000;
E = 150;
S0 = N - E;

m = 1.8;
c = 0.001;

% PVI a resolver
dM = @(t, M) m * (N - S0*exp(-c/m*M) - M);

% Configurar opciones para ode45
options = odeset('AbsTol', 1e-8, 'RelTol', 1e-4);

% Intervalo donde queremos la solucion
tspan = [0, 10];

% Condicion inicial
M0 = 0;

[t, M] = ode45(dM, tspan, M0, options);

% Personas sanas
S = S0*exp(-c/m * M);

% Personas enfermas
E = N - S - M;

% Graficar
plot(t, S, 'r', t, M, 'g', t, E, 'b'); grid on
xlabel('Tiempo [semanas]')
legend('Sanos', 'Muertos', 'Enfermos')

% 1.3 Aproximadamente despues de 7 semanas se estabilizan las variables.
% 1.4 Podemos utilizar ode45 + deval para responder esta pregunta

M = ode45(dM, tspan, M0, options);
deval(M, 8)

% Del grafico y de lo obtenido con deval, la cantidad de muertos luego de 8
% semanas es de 2118 muertos.
